@@ -12,6 +12,9 @@
 #ifndef LIBC_MUSL
 # define LIBC_MUSL 4
 #endif
+#ifndef HEAP_TRAMPOLINES_INIT
+# define HEAP_TRAMPOLINES_INIT 0
+#endif
 #ifndef TARGET_DEFAULT_ISA_SPEC
 # define TARGET_DEFAULT_ISA_SPEC ISA_SPEC_CLASS_20191213
 #endif
@@ -19,7 +22,7 @@
 # define TARGET_RISCV_ATTRIBUTE 1
 #endif
 #ifndef TARGET_RISCV_DEFAULT_ARCH
-# define TARGET_RISCV_DEFAULT_ARCH rv64gc
+# define TARGET_RISCV_DEFAULT_ARCH rv64imafdc_zicsr_zifencei
 #endif
 #ifndef TARGET_RISCV_DEFAULT_ABI
 # define TARGET_RISCV_DEFAULT_ABI lp64d
